@@ -1,4 +1,4 @@
-/* Copyright (C) 1991, 1992, 1993 Free Software Foundation, Inc.
+/* Copyright (C) 1991, 1993, 1994 Free Software Foundation, Inc.
 This file is part of the GNU C Library.
 
 The GNU C Library is free software; you can redistribute it and/or
@@ -20,14 +20,7 @@ Cambridge, MA 02139, USA.  */
 #include <stdio.h>
 #include <string.h>
 
-#if !defined(HAVE_GNU_LD) && !defined (__ELF__)
-#define _sys_errlist sys_errlist
-#define _sys_nerr sys_nerr
-#endif
-
-#if NLS
-#include "nl_types.h"
-#endif
+extern char *_strerror_internal __P ((int, char buf[1024]));
 
 /* Return a string descibing the errno code in ERRNUM.
    The storage is good only until the next call to strerror.
@@ -35,27 +28,6 @@ Cambridge, MA 02139, USA.  */
 char *
 DEFUN(strerror, (errnum), int errnum)
 {
-#if NLS
-  libc_nls_init();
-#endif
-
-  if (errnum < 0 || errnum >= _sys_nerr)
-    {
-      static char unknown_error[] = "Unknown error 000000000000000000000";
-      static char fmt[] = "Unknown error %d";
-#ifdef __linux__
-      sprintf(unknown_error, fmt, errnum);
-#else
-      size_t len = sprintf(unknown_error, fmt, errnum);
-      if (len < sizeof(fmt) - 2)
-	return NULL;
-      unknown_error[len] = '\0';
-#endif
-      return unknown_error;
-    }
-#if NLS
-  return catgets(_libc_cat, ErrorListSet, errnum +1, (char *) _sys_errlist[errnum]);
-#else
-  return (char *) _sys_errlist[errnum];
-#endif
+  static char buf[1024];
+  return _strerror_internal (errnum, buf);
 }
