@@ -31,6 +31,7 @@ register char * __res;
 __asm__("subl %0,%1\n\t"
 	"subl $4,%0\n"		/* prepare loop counter */
 
+	ALIGN
 	/* Four times unfolded loop with only one loop counter.  This
 	 * is achieved by the use of index+base adressing mode.  As the
 	 * loop counter we use the destination address because this is
@@ -41,7 +42,7 @@ LL(1)	"\taddl $4,%0\n\t"	/* increment loop counter */
 	"movb (%0,%1),%%dl\n\t"	/* load current char */
 	"movb %%dl,(%0)\n\t"	/* and store it */
 	"testb %%dl,%%dl\n\t"	/* was is NULL ? */
-	"je " LF(2) "\n\t"	/* yes, than exit */
+	"je " LF(2) "\n\t"	/* yes, then exit */
 	"movb 1(%0,%1),%%dl\n\t"
 	"movb %%dl,1(%0)\n\t"
 	"testb %%dl,%%dl\n\t"
